@@ -6,4 +6,4 @@ app = FastAPI()
 
 @app.get("/pydantic", response_class=RedirectResponse, status_code=302)
 async def redirect_pydantic():
-    return "https://pydantic-docs.helpmanual.io/"
+    return "https://docs.pydantic.dev/"
