@@ -1,6 +1,6 @@
 import strawberry
 from fastapi import FastAPI
-from strawberry.asgi import GraphQL
+from strawberry.fastapi import GraphQLRouter
 
 
 @strawberry.type
@@ -19,8 +19,7 @@ class Query:
 schema = strawberry.Schema(query=Query)
 
 
-graphql_app = GraphQL(schema)
+graphql_app = GraphQLRouter(schema)
 
 app = FastAPI()
-app.add_route("/graphql", graphql_app)
-app.add_websocket_route("/graphql", graphql_app)
+app.include_router(graphql_app, prefix="/graphql")
