@@ -4,5 +4,5 @@ app = FastAPI()
 
 
 @app.get("/items/")
-async def read_items(user_agent: str | None = Header(None)):
+async def read_items(user_agent: str | None = Header(default=None)):
     return {"User-Agent": user_agent}
