@@ -10,6 +10,6 @@ app = FastAPI()
 async def read_items(
     strange_header: Annotated[
         Union[str, None], Header(convert_underscores=False)
-    ] = None
+    ] = None,
 ):
     return {"strange_header": strange_header}
