@@ -14,7 +14,7 @@ async def read_items(
             description="Query string for the items to search in the database that have a good match",
             min_length=3,
         ),
-    ] = None
+    ] = None,
 ):
     results = {"items": [{"item_id": "Foo"}, {"item_id": "Bar"}]}
     if q:
