@@ -4,7 +4,6 @@ import pytest
 from dirty_equals import IsDict
 from fastapi import APIRouter, Depends, FastAPI
 from fastapi.testclient import TestClient
-from fastapi.utils import match_pydantic_error_url
 
 app = FastAPI()
 
@@ -63,7 +62,6 @@ def test_main_depends():
                     "loc": ["query", "q"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
@@ -110,7 +108,6 @@ def test_decorator_depends():
                     "loc": ["query", "q"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
@@ -151,7 +148,6 @@ def test_router_depends():
                     "loc": ["query", "q"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
@@ -198,7 +194,6 @@ def test_router_decorator_depends():
                     "loc": ["query", "q"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
@@ -285,7 +280,6 @@ def test_override_with_sub_main_depends():
                     "loc": ["query", "k"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
@@ -316,7 +310,6 @@ def test_override_with_sub__main_depends_q_foo():
                     "loc": ["query", "k"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
@@ -355,7 +348,6 @@ def test_override_with_sub_decorator_depends():
                     "loc": ["query", "k"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
@@ -386,7 +378,6 @@ def test_override_with_sub_decorator_depends_q_foo():
                     "loc": ["query", "k"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
@@ -425,7 +416,6 @@ def test_override_with_sub_router_depends():
                     "loc": ["query", "k"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
@@ -456,7 +446,6 @@ def test_override_with_sub_router_depends_q_foo():
                     "loc": ["query", "k"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
@@ -495,7 +484,6 @@ def test_override_with_sub_router_decorator_depends():
                     "loc": ["query", "k"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
@@ -526,7 +514,6 @@ def test_override_with_sub_router_decorator_depends_q_foo():
                     "loc": ["query", "k"],
                     "msg": "Field required",
                     "input": None,
-                    "url": match_pydantic_error_url("missing"),
                 }
             ]
         }
