@@ -7,7 +7,7 @@ from pathlib import PurePath, PurePosixPath, PureWindowsPath
 from typing import Optional
 
 import pytest
-from fastapi._compat import PYDANTIC_V2
+from fastapi._compat import PYDANTIC_V2, Undefined
 from fastapi.encoders import jsonable_encoder
 from pydantic import BaseModel, Field, ValidationError
 
@@ -247,8 +247,9 @@ def test_encode_model_with_pure_path():
             class Config:
                 arbitrary_types_allowed = True
 
-    obj = ModelWithPath(path=PurePath("/foo", "bar"))
-    assert jsonable_encoder(obj) == {"path": "/foo/bar"}
+    test_path = PurePath("/foo", "bar")
+    obj = ModelWithPath(path=test_path)
+    assert jsonable_encoder(obj) == {"path": str(test_path)}
 
 
 def test_encode_model_with_pure_posix_path():
@@ -309,3 +310,9 @@ def test_encode_deque_encodes_child_models():
     dq = deque([Model(test="test")])
 
     assert jsonable_encoder(dq)[0]["test"] == "test"
+
+
+@needs_pydanticv2
+def test_encode_pydantic_undefined():
+    data = {"value": Undefined}
+    assert jsonable_encoder(data) == {"value": None}
