@@ -1,9 +1,16 @@
+import pytest
+from fastapi import FastAPI
 from fastapi.testclient import TestClient
 
-from docs_src.events.tutorial002 import app
+
+@pytest.fixture(name="app", scope="module")
+def get_app():
+    with pytest.warns(DeprecationWarning):
+        from docs_src.events.tutorial002 import app
+    yield app
 
 
-def test_events():
+def test_events(app: FastAPI):
     with TestClient(app) as client:
         response = client.get("/items/")
         assert response.status_code == 200, response.text
@@ -12,7 +19,7 @@ def test_events():
         assert "Application shutdown" in log.read()
 
 
-def test_openapi_schema():
+def test_openapi_schema(app: FastAPI):
     with TestClient(app) as client:
         response = client.get("/openapi.json")
         assert response.status_code == 200, response.text
